import { Locales } from "./tsdefaults";
import { TSDate } from "./tsdate";
import { country, language, uint } from "./types";
import { TSCountry } from "./tscountry";
export interface TimeComp {
    hour: uint;
    minute: uint;
    second: uint;
}
export interface TSDateComp extends TimeComp {
    year: uint;
    month: uint;
    day: uint;
    dayOfWeek?: uint;
}
export interface TSDurationComp {
    days: uint;
    hours: uint;
    minutes: uint;
    seconds: uint;
}
export declare enum TSDateForm {
    Standard = 0,
    English = 1,
    Computer = 2,
    ISO8601 = 3,
    ISO8601C = 4
}
export declare enum TSDateRep {
    LocalTime = "lt",
    LocalDate = "ld",
    LocalDateTime = "ldt",
    ShortLocalDate = "sld",
    ShortLocalDateTime = "sldt"
}
/**
 * If you call timecomponents() with no parameters, it
 * returns the components for the current local time.
 * This function can not have a string as parameter ;
 * in order to create components from string, you need
 * to user functions $parsetime()
 */
export declare function $timecomponents(source?: number | Date | TSDate | null | undefined): TimeComp;
/**
 * If you call components() with no parameters, it
 * returns the components for the current local date.
 * This function can not have a string as parameter ;
 * in order to create components from string, you need
 * to user functions $parsedate(), $parsedatetime() or $isostring2components()
 */
export declare function $components(source?: number | Date | TSDate | null | undefined): TSDateComp;
export declare function $componentsarevalid(comp: TSDateComp | null | undefined): boolean;
export declare function $componentshavetime(c: TSDateComp): boolean;
export declare function $parsetime(s: string | null | undefined): TimeComp | null;
/**
 * These 2 functions parse a date or a date time.
 * Dependending on which date-form you choose to parse the given string, you may ommit
 * the month or the year, the system will autocomplete the components itself ; you
 * also may enter the year with 2 or 4 digits and the system will try to interpret
 * all 2 digits years as years from the previous or the current century. The limit
 * for that is : all date that seems to be more than 20 years in the future will
 * be considered as a previous century year. Note that if you date is not complete
 * you won't be able to enter a time.
 *
 * If you want to create a TSDate from a parsed string, you don't need this
 * function. Simply call :
 *
 *   myDate = TSDate.fromString(myStringToParse [, dateForm]) ; // this does not throw but return can be null
 *
 * ==WARNING== dayOfWeek is not initialized after parsing.
 */
export declare function $parsedatetime(s: string | null | undefined, form?: TSDateForm): TSDateComp | null;
export declare function $parsedate(s: string | null | undefined, form?: TSDateForm): TSDateComp | null;
/**
 * This function parse an ISO8601 OR ISO3339 date string. In both case, you may
 * enter the year with 2 or 4 digits and the system will try to interpret
 * all 2 digits years as years from the previous or the current century. The limit
 * for that is : all date that seems to be more than 20 years in the future will
 * be considered as a previous century year. We also admit to have only day dates
 * (e.g no time specified) which is normally impossible with ISO3339. On the contrary,
 * we force the use of the T or t separator between day & time which is not the case is 3339.
 * Finany and it is VERY IMPORTANT: since TSDate and TSDateComp deal with
 * local dates (dates with no time zone at all), the time zone information
 * MUST NOT BE PRESENT AT THE END OF THE PARSED STRING.
 *
 * In order to create a TSDate from a string you don't need this function. You simply use :
 *
 *  date = new TSDate(anISODateString) ; // this throw an error if the parsed string is wrong
 *
 * But, as we know,  a lot of programmers use GMT dates as local dates and you also may get
 * string dates comming from an API and expressed in GMT. For that reason, we acccept that the
 * indication of the GMT time zone (but no other one) can be present at the end of the string to
 * parse. This indication may come with the Z letter of something like +00 or +0000 or +00:00.
 *
 * This facility to consider GMT dates as "no time zone date" is offered at the entire responsability
 * of the user programmer.
 *
 * ==WARNING== dayOfWeek is not initialized after parsing.
 */
export interface Iso8601ParseOptions {
    noTime?: boolean;
}
export declare function $isostring2components(source: string | null | undefined, opts?: Iso8601ParseOptions): TSDateComp | null;
export declare function $components2timestamp(c: TSDateComp): number;
export declare function $components2date(c: TSDateComp): Date;
export declare function $components2string(c: TSDateComp, form?: TSDateForm): string;
/**
 *      Format documentation :
 *
 *      %Y  year padded to 4 digits
 *      %y  year paddeed to 2 digits (centuries are ommited)
 *      %z  non padded year
 *
 *      %m  month padded to 2 digits
 *      %n  not padded month
 *      %b  short month name
 *      %B  month name
 *
 *      %d  day padded to 2 digits
 *      %e  not padded day
 *
 *      %f  day of week (0 = sunday, 1 = monday, ..., 6 = Saturday)
 *      %F  day of week calculated with the current local starting day (0 = monday in France)
 *      %a  short day of week name
 *      %A  day of week name
 *
 *      %q  day of year padded to 3 digits
 *      %r  not padded day of year
 *
 *      %H  24 hour representation padded to 2 digits
 *      %I  12 hour representation padded to 2 digits
 *      %J  not padded 24 hour representation of hours
 *      %K  not padded 12 hour representation of hours
 *      %M  minutes padded to 2 digits
 *      %N  not padded minutes
 *      %P  AM/PM
 *      %S  seconds padded to 2 digits
 *      %T  not padded seconds
 *
 *      %p  standard partial time format for the given language (time without seconds)
 *      %t  standard time format for the given language
 *
 *      %v  week of year padded to 2 digits
 *      %w  not padded week of year
 *
 *      %x  standard short date format for the given language
 *      %X  standard date format for the given language
 *
 *      %%  % caracter
 *      %[  enters a format zone which will be disabled if the passed date has no time
 *      %]  exit previous format zone without time
 */
export declare function $components2stringformat(comp: TSDateComp, format?: string | TSDateRep | undefined | null, locale?: language | country | TSCountry | Locales | null | undefined): string | null;
export declare function $durationcomponents(duration: number | null | undefined): TSDurationComp;
export declare function $duration(comps: TSDurationComp): number;
export declare function duration2String(comps: TSDurationComp): string;
export declare function durationNumber2String(duration: number | null | undefined): string;
